# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`facter`](#facter): Manage facter

### Defined types

* [`facter::fact`](#facterfact): Define txt based external facts
* [`facter::structured_data_fact`](#facterstructured_data_fact): Define YAML based external structured data facts.

## Classes

### <a name="facter"></a>`facter`

This class will manage facter and allow you to specify external facts.

#### Parameters

The following parameters are available in the `facter` class:

* [`manage_facts_d_dir`](#manage_facts_d_dir)
* [`purge_facts_d`](#purge_facts_d)
* [`facts_d_dir`](#facts_d_dir)
* [`facts_d_owner`](#facts_d_owner)
* [`facts_d_group`](#facts_d_group)
* [`facts_d_mode`](#facts_d_mode)
* [`path_to_facter`](#path_to_facter)
* [`path_to_facter_symlink`](#path_to_facter_symlink)
* [`ensure_facter_symlink`](#ensure_facter_symlink)
* [`facts_hash`](#facts_hash)
* [`structured_data_facts_hash`](#structured_data_facts_hash)
* [`facts_file`](#facts_file)
* [`facts_file_owner`](#facts_file_owner)
* [`facts_file_group`](#facts_file_group)
* [`facts_file_mode`](#facts_file_mode)

##### <a name="manage_facts_d_dir"></a>`manage_facts_d_dir`

Data type: `Boolean`

Boolean to determine if the external facts directory will be managed.

Default value: ``true``

##### <a name="purge_facts_d"></a>`purge_facts_d`

Data type: `Boolean`

Boolean to determine if the external facts directory should be purged. This
will remove files not managed by Puppet.

Default value: ``false``

##### <a name="facts_d_dir"></a>`facts_d_dir`

Data type: `Stdlib::Absolutepath`

Path to the directory which will contain the external facts.

Default value: `'/etc/facter/facts.d'`

##### <a name="facts_d_owner"></a>`facts_d_owner`

Data type: `String[1]`

The owner of the `facts_d_dir`.

Default value: `'root'`

##### <a name="facts_d_group"></a>`facts_d_group`

Data type: `String[1]`

The group of the `facts_d_dir`.

Default value: `'root'`

##### <a name="facts_d_mode"></a>`facts_d_mode`

Data type: `Optional[Stdlib::Filemode]`

The mode of the `facts_d_dir`.

Default value: `'0755'`

##### <a name="path_to_facter"></a>`path_to_facter`

Data type: `Stdlib::Absolutepath`

The path to the facter binary.

Default value: `'/opt/puppetlabs/bin/facter'`

##### <a name="path_to_facter_symlink"></a>`path_to_facter_symlink`

Data type: `Stdlib::Absolutepath`

Path to a symlink that points to the facter binary.

Default value: `'/usr/local/bin/facter'`

##### <a name="ensure_facter_symlink"></a>`ensure_facter_symlink`

Data type: `Boolean`

Boolean to determine if the symlink should be present.

Default value: ``false``

##### <a name="facts_hash"></a>`facts_hash`

Data type: `Hash`

A hash of `facter::fact` entries.

Default value: `{}`

##### <a name="structured_data_facts_hash"></a>`structured_data_facts_hash`

Data type: `Hash`

A hash of `facter::structured_data_fact` entries.

Default value: `{}`

##### <a name="facts_file"></a>`facts_file`

Data type: `Pattern[/\.txt*\Z/]`

The file in which the text based external facts are stored. This file must
end with '.txt'.

Default value: `'facts.txt'`

##### <a name="facts_file_owner"></a>`facts_file_owner`

Data type: `String[1]`

The owner of the facts_file.

Default value: `'root'`

##### <a name="facts_file_group"></a>`facts_file_group`

Data type: `String[1]`

The group of the facts_file.

Default value: `'root'`

##### <a name="facts_file_mode"></a>`facts_file_mode`

Data type: `Optional[Stdlib::Filemode]`

The mode of the facts_file.

Default value: `'0644'`

## Defined types

### <a name="facterfact"></a>`facter::fact`

Define txt based external facts

#### Parameters

The following parameters are available in the `facter::fact` defined type:

* [`value`](#value)
* [`fact`](#fact)
* [`file`](#file)
* [`facts_dir`](#facts_dir)

##### <a name="value"></a>`value`

Data type: `String[1]`

Value of the fact.

##### <a name="fact"></a>`fact`

Data type: `String[1]`

Name of the fact

Default value: `$name`

##### <a name="file"></a>`file`

Data type: `Optional[String[1]]`

File in which the fact will be placed. If not specified, use the default
facts file.

Default value: ``undef``

##### <a name="facts_dir"></a>`facts_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Directory in which the file will be placed. If not specified, use the
default facts_d_dir.

Default value: ``undef``

### <a name="facterstructured_data_fact"></a>`facter::structured_data_fact`

Define YAML based external structured data facts.

#### Parameters

The following parameters are available in the `facter::structured_data_fact` defined type:

* [`data`](#data)
* [`file`](#file)
* [`facts_dir`](#facts_dir)

##### <a name="data"></a>`data`

Data type: `Hash[String[1], Data]`

A hash of facts. All keys must be strings.

##### <a name="file"></a>`file`

Data type: `Pattern[/\.yaml*\Z/]`

File in which the fact will be placed. The file name must end with '.yaml'.

Default value: `'facts.yaml'`

##### <a name="facts_dir"></a>`facts_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Directory in which the file will be placed. If not specified, use the
default facts_d_dir.

Default value: ``undef``

